#include "Testboard_ui.h"

///////////////////// VARIABLES ////////////////////
lv_obj_t * Screen1;
lv_obj_t * Sfondo1;
lv_obj_t * Slider1;

///////////////////// IMAGES ////////////////////

///////////////////// FUNCTIONS ////////////////////
#define BAR_PROPERTY_VALUE 0
#define BAR_PROPERTY_VALUE_WITH_ANIM 1

void SetBarProperty(lv_obj_t * target, int id, int val)
{
    if(id == BAR_PROPERTY_VALUE_WITH_ANIM) lv_bar_set_value(target, val, LV_ANIM_ON);
    if(id == BAR_PROPERTY_VALUE) lv_bar_set_value(target, val, LV_ANIM_OFF);
}

#define BASIC_PROPERTY_POSITION_X 0
#define BASIC_PROPERTY_POSITION_Y 1
#define BASIC_PROPERTY_WIDTH 2
#define BASIC_PROPERTY_HEIGHT 3
#define BASIC_PROPERTY_CLICKABLE 4
#define BASIC_PROPERTY_HIDDEN 5
#define BASIC_PROPERTY_DRAGABLE 6
#define BASIC_PROPERTY_DISABLED 7

void SetBasicProperty(lv_obj_t * target, int id, int val)
{
    if(id == BASIC_PROPERTY_POSITION_X) lv_obj_set_x(target, val);
    if(id == BASIC_PROPERTY_POSITION_Y) lv_obj_set_y(target, val);
    if(id == BASIC_PROPERTY_WIDTH) lv_obj_set_width(target, val);
    if(id == BASIC_PROPERTY_HEIGHT) lv_obj_set_height(target, val);
}

void SetBasicPropertyB(lv_obj_t * target, int id, bool val)
{
    if(id == BASIC_PROPERTY_CLICKABLE) lv_obj_set_click(target, val);
    if(id == BASIC_PROPERTY_HIDDEN) lv_obj_set_hidden(target, val);
    if(id == BASIC_PROPERTY_DRAGABLE) lv_obj_set_drag(target, val);
    if(id == BASIC_PROPERTY_DISABLED) {
        if(val) lv_obj_add_state(target, LV_STATE_DISABLED);
        else lv_obj_clear_state(target, LV_STATE_DISABLED);
    }
}

#define BUTTON_PROPERTY_TOGGLE 0
#define BUTTON_PROPERTY_CHECKED 1

void SetButtonProperty(lv_obj_t * target, int id, bool val)
{
    if(id == BUTTON_PROPERTY_TOGGLE) lv_btn_toggle(target);
    if(id == BUTTON_PROPERTY_CHECKED) lv_btn_set_state(target, val ? LV_BTN_STATE_CHECKED_RELEASED : LV_BTN_STATE_RELEASED);
}

#define DROPDOWN_PROPERTY_SELECTED 0

void SetDropdownProperty(lv_obj_t * target, int id, int val)
{
    if(id == DROPDOWN_PROPERTY_SELECTED) lv_dropdown_set_selected(target, val);
}

#define IMAGE_PROPERTY_IMAGE 0

void SetImageProperty(lv_obj_t * target, int id, uint8_t * val)
{
    if(id == IMAGE_PROPERTY_IMAGE) lv_img_set_src(target, val);
}

#define LABEL_PROPERTY_TEXT 0

void SetLabelProperty(lv_obj_t * target, int id, char * val)
{
    if(id == LABEL_PROPERTY_TEXT) lv_label_set_text(target, val);
}

#define ROLLER_PROPERTY_SELECTED 0
#define ROLLER_PROPERTY_SELECTED_WITH_ANIM 1

void SetRollerProperty(lv_obj_t * target, int id, int val)
{
    if(id == ROLLER_PROPERTY_SELECTED_WITH_ANIM) lv_roller_set_selected(target, val, LV_ANIM_ON);
    if(id == ROLLER_PROPERTY_SELECTED) lv_roller_set_selected(target, val, LV_ANIM_OFF);
}

#define SLIDER_PROPERTY_VALUE 0
#define SLIDER_PROPERTY_VALUE_WITH_ANIM 1

void SetSliderProperty(lv_obj_t * target, int id, int val)
{
    if(id == SLIDER_PROPERTY_VALUE_WITH_ANIM) lv_slider_set_value(target, val, LV_ANIM_ON);
    if(id == SLIDER_PROPERTY_VALUE) lv_slider_set_value(target, val, LV_ANIM_OFF);
}

void ChangeScreen(lv_obj_t * target, int fademode, int spd, int delay)
{
    lv_scr_load_anim(target, fademode, spd, delay, false);
}

void SetOpacity(lv_obj_t * target, int val)
{
    lv_obj_set_style_local_opa_scale(target, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, val);
}

void anim_callback_set_x(lv_anim_t * a, lv_anim_value_t v)
{
    lv_obj_set_x(a->user_data, v);
}

void anim_callback_set_y(lv_anim_t * a, lv_anim_value_t v)
{
    lv_obj_set_y(a->user_data, v);
}

void anim_callback_set_width(lv_anim_t * a, lv_anim_value_t v)
{
    lv_obj_set_width(a->user_data, v);
}

void anim_callback_set_height(lv_anim_t * a, lv_anim_value_t v)
{
    lv_obj_set_height(a->user_data, v);
}

///////////////////// ANIMATIONS ////////////////////

///////////////////// FUNCTIONS2 ////////////////////
static void Slider1_eventhandler(lv_obj_t * obj, lv_event_t event)
{
}

///////////////////// SCREENS ////////////////////
void BuildPages(void)
{
    Screen1 = lv_obj_create(NULL, NULL);

    Sfondo1 = lv_obj_create(Screen1, NULL);
    lv_obj_set_click(Sfondo1, false);
    lv_obj_set_hidden(Sfondo1, false);
    lv_obj_clear_state(Sfondo1, LV_STATE_DISABLED);
    lv_obj_set_size(Sfondo1, 480, 320);  // force: 0
    lv_obj_align(Sfondo1, Screen1, LV_ALIGN_CENTER, 0, 0); // force: 480
    lv_obj_set_drag(Sfondo1, false);
    lv_obj_set_style_local_bg_color(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT,
                                    lv_color_hex(48 * 256 * 256 + 169 * 256 + 192));
    lv_obj_set_style_local_bg_opa(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_bg_grad_color(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT,
                                         lv_color_hex(6 * 256 * 256 + 38 * 256 + 52));
    lv_obj_set_style_local_bg_main_stop(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 0);
    lv_obj_set_style_local_bg_grad_stop(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 320);
    lv_obj_set_style_local_radius(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 80);
    lv_obj_set_style_local_bg_grad_dir(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, LV_GRAD_DIR_VER);
    lv_obj_set_style_local_border_color(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT,
                                        lv_color_hex(0 * 256 * 256 + 0 * 256 + 0));
    lv_obj_set_style_local_border_opa(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_border_width(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 2);
    lv_obj_set_style_local_border_side(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, LV_BORDER_SIDE_FULL);
    lv_obj_set_style_local_shadow_color(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT,
                                        lv_color_hex(0 * 256 * 256 + 0 * 256 + 0));
    lv_obj_set_style_local_shadow_opa(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_shadow_width(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 60);
    lv_obj_set_style_local_shadow_spread(Sfondo1, LV_BTN_PART_MAIN, LV_STATE_DEFAULT, 10);

    Slider1 = lv_slider_create(Screen1, NULL);
    lv_obj_set_size(Slider1, 285, 5);
    lv_obj_align(Slider1, Screen1, LV_ALIGN_CENTER, 0, 0);
    lv_slider_set_range(Slider1, 0, 255);
    lv_slider_set_type(Slider1, LV_SLIDER_TYPE_NORMAL);
    lv_slider_set_value(Slider1, 128, LV_ANIM_OFF);
    lv_slider_set_left_value(Slider1, 0, LV_ANIM_OFF);
    lv_obj_set_click(Slider1, true);
    lv_obj_set_hidden(Slider1, false);
    lv_obj_set_event_cb(Slider1, Slider1_eventhandler);
    lv_obj_clear_state(Slider1, LV_STATE_DISABLED);
    lv_obj_set_drag(Slider1, true);
    lv_obj_set_style_local_bg_color(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT,
                                    lv_color_hex(0 * 256 * 256 + 0 * 256 + 0));
    lv_obj_set_style_local_bg_opa(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_bg_grad_color(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT,
                                         lv_color_hex(248 * 256 * 256 + 255 * 256 + 190));
    lv_obj_set_style_local_bg_grad_dir(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, LV_GRAD_DIR_HOR);
    lv_obj_set_style_local_shadow_color(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT,
                                        lv_color_hex(0 * 256 * 256 + 0 * 256 + 0));
    lv_obj_set_style_local_shadow_opa(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, 200);
    lv_obj_set_style_local_shadow_width(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, 40);
    lv_obj_set_style_local_shadow_spread(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, 5);
    lv_obj_set_style_local_shadow_ofs_x(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, 0);
    lv_obj_set_style_local_shadow_ofs_y(Slider1, LV_SLIDER_PART_BG, LV_STATE_DEFAULT, 5);

    lv_obj_set_style_local_bg_color(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT,
                                    lv_color_hex(107 * 256 * 256 + 0 * 256 + 0));
    lv_obj_set_style_local_bg_opa(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_bg_grad_color(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT,
                                         lv_color_hex(194 * 256 * 256 + 198 * 256 + 0));
    lv_obj_set_style_local_bg_grad_dir(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT, LV_GRAD_DIR_HOR);
    lv_obj_set_style_local_outline_color(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT,
                                         lv_color_hex(254 * 256 * 256 + 255 * 256 + 227));
    lv_obj_set_style_local_outline_opa(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_outline_width(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT, 1);
    lv_obj_set_style_local_outline_pad(Slider1, LV_SLIDER_PART_INDIC, LV_STATE_DEFAULT, 2);

    lv_obj_set_style_local_bg_color(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT,
                                    lv_color_hex(166 * 256 * 256 + 254 * 256 + 164));
    lv_obj_set_style_local_bg_opa(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT, 255);
    lv_obj_set_style_local_bg_grad_color(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT,
                                         lv_color_hex(6 * 256 * 256 + 36 * 256 + 5));
    lv_obj_set_style_local_bg_grad_dir(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT, LV_GRAD_DIR_VER);
    lv_obj_set_style_local_shadow_color(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT,
                                        lv_color_hex(183 * 256 * 256 + 254 * 256 + 211));
    lv_obj_set_style_local_shadow_opa(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT, 200);
    lv_obj_set_style_local_shadow_width(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT, 60);
    lv_obj_set_style_local_shadow_spread(Slider1, LV_SLIDER_PART_KNOB, LV_STATE_DEFAULT, 20);

}

